From 24897c2e55debf87b9ff3eb03bb3ad1515736eac Mon Sep 17 00:00:00 2001
From: ldam <ldam@passcal.nmt.edu>
Date: Fri, 6 Oct 2023 08:52:20 -0600
Subject: [PATCH] change label Data Card to Memory Card

---
 sohstationviewer/view/main_window.py | 6 +++---
 sohstationviewer/view/ui/main_ui.py  | 2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/sohstationviewer/view/ui/main_ui.py b/sohstationviewer/view/ui/main_ui.py
index 3faa3ce6e..a9a97a7e1 100755
--- a/sohstationviewer/view/ui/main_ui.py
+++ b/sohstationviewer/view/ui/main_ui.py
@@ -404,7 +404,7 @@ class UIMainWindow(object):
         read_option_grid = QGridLayout()
         left_layout.addLayout(read_option_grid)
         self.from_data_card_check_box = QCheckBox(
-            'From Data Card', self.central_widget)
+            'From Memory Card', self.central_widget)
         read_option_grid.addWidget(self.from_data_card_check_box, 0, 0, 1, 2)
 
         self.replot_button = QPushButton('RePlot', self.central_widget)
diff --git a/sohstationviewer/view/main_window.py b/sohstationviewer/view/main_window.py
index 2288193c2..93064bebf 100755
--- a/sohstationviewer/view/main_window.py
+++ b/sohstationviewer/view/main_window.py
@@ -494,7 +494,7 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
                 raise Exception(msg)
             self.data_type = 'RT130'
         elif self.from_data_card_check_box.isChecked():
             # When "From Data Card" checkbox is checked, no sub directories
             # displayed in File List box. The current dir (root_dir) will be
             # the only one of the selected dir for user to start processing
             # from.
@@ -508,7 +508,7 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
                 else:
                     self.list_of_dir = [root_dir.joinpath('sdata')]
         else:
             # When "From Data Card" checkbox is checked, sub directories of the
             # current dir (root_dir) will be displayed in File List box.
             # User can select one or more sub-directories to process from.
             self.list_of_dir = [
@@ -950,7 +950,7 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
                     self.open_files_list.addItem(FileListItem(rt130_das))
 
             elif self.from_data_card_check_box.isChecked():
-                self.open_files_list.addItem('Data Card')
+                self.open_files_list.addItem('Memory Card')
                 self.tracking_info_text_browser.setText(
                     "Please select the card by clicking on button "
                     "'Main Data Directory'.")
@@ -494,7 +494,7 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
             self.data_type = 'RT130'
         elif self.from_data_card_check_box.isChecked():
-            # When "From Data Card" checkbox is checked, no sub directories
+            # When "From Memory Card" checkbox is checked, no sub directories
             # displayed in File List box. The current dir (root_dir) will be
             # the only one of the selected dir for user to start processing
@@ -508,7 +508,7 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
                     self.list_of_dir = [root_dir.joinpath('sdata')]
         else:
-            # When "From Data Card" checkbox is checked, sub directories of the
+            # When "From Memory Card" checkbox is checked, sub directories of the
             # current dir (root_dir) will be displayed in File List box.
             # User can select one or more sub-directories to process from.
-- 
GitLab